#[repr(C)]pub struct BootInfo {
pub framebuffer: Framebuffer,
}Expand description
Boot-time data provided by roxy-loader.
This is the main value passed to the kernel entry point. It groups together the information a kernel can use immediately after startup.
Fields
framebuffer: FramebufferInformation about the framebuffer that the kernel can draw to.