pub struct Framebuffer {
pub size: usize,
pub stride: usize,
pub pixel_format: PixelFormat,
pub width: usize,
pub height: usize,
/* private fields */
}Expand description
A framebuffer provided to the kernel at boot time.
Kernels can use this value to find the framebuffer memory and understand its basic layout.
Fields
size: usizeThe total size of the framebuffer in bytes.
stride: usizeThe number of pixels in each row of the framebuffer.
pixel_format: PixelFormatPixel format of the framebuffer.
width: usizeWidth of the framebuffer in pixels.
height: usizeHeight of the framebuffer in pixels.
Implementations