pub struct Framebuffer {
pub size: usize,
pub stride: usize,
/* private fields */
}Expand description
A framebuffer provided to the kernel at boot time.
Kernels can use this value to find the framebuffer memory and understand its basic layout.
Fields
size: usizeThe total size of the framebuffer in bytes.
stride: usizeThe number of pixels in each row of the framebuffer.
Implementations