kernel_entry

Macro kernel_entry 

macro_rules! kernel_entry {
    ($kernel_main:ident) => { ... };
}
Defines the entry point used by kernels started with roxy-loader.

Use this macro in the crate that contains your kernel entry function. It connects your function to the startup convention expected by roxy-loader.

Examples

#![no_std]
#![no_main]

use roxy_loader_api::{bootinfo::BootInfo, kernel_entry};

kernel_entry!(kernel_main);

fn kernel_main(bootinfo: &BootInfo) -> ! {
    let _framebuffer = bootinfo.framebuffer;

    loop {}
}